==> touhoulittlemaid-fabric-1.20.1-0.1.0-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityGomoku.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import com.github.tartaricacid.touhoulittlemaid.api.block.IBoardGameEntityBlock;
import com.github.tartaricacid.touhoulittlemaid.api.game.gomoku.Point;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2495;
import net.minecraft.class_2499;
import net.minecraft.class_2520;
import net.minecraft.class_2591;
import net.minecraft.class_2680;

public class TileEntityGomoku extends TileEntityJoy implements IBoardGameEntityBlock, IBlockEntityPersistentData {
    public static final class_2591<TileEntityGomoku> TYPE = class_2591.class_2592.method_20528(TileEntityGomoku::new, InitBlocks.GOMOKU).method_11034(null);
    private static final String CHESS_DATA = "ChessData";
    private static final String IN_PROGRESS = "InProgress";
    private static final String PLAYER_TURN = "PlayerTurn";
    private static final String CHESS_COUNTER = "ChessCounter";
    private static final String LATEST_CHESS_POINT = "LatestChessPoint";
    private int[][] chessData = new int[15][15];
    private boolean inProgress = true;
    private boolean playerTurn = true;
    private int chessCounter = 0;
    private Point latestChessPoint = Point.NULL;

    public TileEntityGomoku(class_2338 pos, class_2680 blockState) {
        super(TYPE, pos, blockState);
    }

    @Override
    protected void method_11007(class_2487 pTag) {
        class_2499 listTag = new class_2499();
        for (int[] chessRow : chessData) {
            listTag.add(new class_2495(chessRow));
        }
        getPersistentData().method_10566(CHESS_DATA, listTag);
        getPersistentData().method_10556(IN_PROGRESS, this.inProgress);
        getPersistentData().method_10556(PLAYER_TURN, this.playerTurn);
        getPersistentData().method_10569(CHESS_COUNTER, this.chessCounter);
        getPersistentData().method_10566(LATEST_CHESS_POINT, Point.toTag(this.latestChessPoint));
        super.method_11007(pTag);
    }

    @Override
    public void method_11014(class_2487 pTag) {
        super.method_11014(pTag);
        class_2499 listTag = getPersistentData().method_10554(CHESS_DATA, class_2520.field_33257);
        for (int i = 0; i < listTag.size(); i++) {
            int[] intArray = listTag.method_36111(i);
            this.chessData[i] = intArray;
        }
        this.inProgress = getPersistentData().method_10577(IN_PROGRESS);
        this.playerTurn = getPersistentData().method_10577(PLAYER_TURN);
        this.chessCounter = getPersistentData().method_10550(CHESS_COUNTER);
        this.latestChessPoint = Point.fromTag(getPersistentData().method_10562(LATEST_CHESS_POINT));
    }

    public void reset() {
        this.chessData = new int[15][15];
        this.inProgress = true;
        this.playerTurn = true;
        this.chessCounter = 0;
        this.latestChessPoint = Point.NULL;
    }

    public int[][] getChessData() {
        return chessData;
    }

    public void setChessData(int x, int y, int type) {
        this.chessData[x][y] = type;
        this.latestChessPoint = new Point(x, y, type);
        this.chessCounter += 1;
        ;
    }

    public boolean isPlayerTurn() {
        return playerTurn;
    }

    public void setPlayerTurn(boolean playerTurn) {
        this.playerTurn = playerTurn;
    }

    public boolean isInProgress() {
        return inProgress;
    }

    public void setInProgress(boolean inProgress) {
        this.inProgress = inProgress;
    }

    public int getChessCounter() {
        return chessCounter;
    }

    public Point getLatestChessPoint() {
        return latestChessPoint;
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.1.7-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityGomoku.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import com.github.tartaricacid.touhoulittlemaid.api.block.IBoardGameEntityBlock;
import com.github.tartaricacid.touhoulittlemaid.api.game.gomoku.Point;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2495;
import net.minecraft.class_2499;
import net.minecraft.class_2520;
import net.minecraft.class_2591;
import net.minecraft.class_2680;

public class TileEntityGomoku extends TileEntityJoy implements IBoardGameEntityBlock {
    public static final class_2591<TileEntityGomoku> TYPE = class_2591.class_2592.method_20528(TileEntityGomoku::new, InitBlocks.GOMOKU).method_11034(null);

    private static final String CHESS_DATA = "ChessData";
    private static final String IN_PROGRESS = "InProgress";
    private static final String PLAYER_TURN = "PlayerTurn";
    private static final String CHESS_COUNTER = "ChessCounter";
    private static final String LATEST_CHESS_POINT = "LatestChessPoint";

    private int[][] chessData = new int[15][15];
    private boolean inProgress = true;
    private boolean playerTurn = true;
    private int chessCounter = 0;
    private Point latestChessPoint = Point.NULL;

    public TileEntityGomoku(class_2338 pos, class_2680 blockState) {
        super(TYPE, pos, blockState);
    }

    @Override
    protected void method_11007(class_2487 tag) {
        class_2499 listTag = new class_2499();
        for (int[] chessRow : chessData) {
            listTag.add(new class_2495(chessRow));
        }
        getPersistentData().method_10566(CHESS_DATA, listTag);
        getPersistentData().method_10556(IN_PROGRESS, this.inProgress);
        getPersistentData().method_10556(PLAYER_TURN, this.playerTurn);
        getPersistentData().method_10569(CHESS_COUNTER, this.chessCounter);
        getPersistentData().method_10566(LATEST_CHESS_POINT, Point.toTag(this.latestChessPoint));
        super.method_11007(tag);
    }

    @Override
    public void method_11014(class_2487 nbt) {
        super.method_11014(nbt);
        class_2499 listTag = getPersistentData().method_10554(CHESS_DATA, class_2520.field_33261);
        for (int i = 0; i < listTag.size(); i++) {
            int[] intArray = listTag.method_36111(i);
            this.chessData[i] = intArray;
        }
        this.inProgress = getPersistentData().method_10577(IN_PROGRESS);
        this.playerTurn = getPersistentData().method_10577(PLAYER_TURN);
        this.chessCounter = getPersistentData().method_10550(CHESS_COUNTER);
        this.latestChessPoint = Point.fromTag(getPersistentData().method_10562(LATEST_CHESS_POINT));
    }

    public void reset() {
        this.chessData = new int[15][15];
        this.inProgress = true;
        this.playerTurn = true;
        this.chessCounter = 0;
        this.latestChessPoint = Point.NULL;
    }

    public int[][] getChessData() {
        return chessData;
    }

    public void setChessData(int x, int y, int type) {
        this.chessData[x][y] = type;
        this.latestChessPoint = new Point(x, y, type);
        this.chessCounter += 1;
    }

    public boolean isPlayerTurn() {
        return playerTurn;
    }

    public void setPlayerTurn(boolean playerTurn) {
        this.playerTurn = playerTurn;
    }

    public boolean isInProgress() {
        return inProgress;
    }

    public void setInProgress(boolean inProgress) {
        this.inProgress = inProgress;
    }

    public int getChessCounter() {
        return chessCounter;
    }

    public Point getLatestChessPoint() {
        return latestChessPoint;
    }
}
